# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/views.py


from __future__ import unicode_literals

from django.shortcuts import render_to_response
try:
    from django.core.urlresolvers import reverse
except ModuleNotFoundError:
    from django.urls import reverse

from opensearch import settings


__all__ = [
    "opensearch",
]


def opensearch(request):
    """
    Return opensearch.xml.
    """

    contact_email = settings.CONTACT_EMAIL
    short_name = settings.SHORT_NAME
    description = settings.DESCRIPTION
    favicon_width = settings.FAVICON_WIDTH
    favicon_height = settings.FAVICON_HEIGHT
    favicon_type = settings.FAVICON_TYPE
    favicon_file = settings.FAVICON_FILE
    url = "{url}?{querystring}{{searchTerms}}".format(**{
        "url": request.build_absolute_uri(reverse(settings.SEARCH_URL)),
        "querystring": settings.SEARCH_QUERYSTRING,
    })
    input_encoding = settings.INPUT_ENCODING.upper()

    return render_to_response("opensearch/opensearch.xml", context=locals(), content_type="application/opensearchdescription+xml")



# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/apps.py


from __future__ import unicode_literals

from django.apps import AppConfig


__all__ = ["Config", ]


class Config(AppConfig):

    name = "opensearch"
    verbose_name = "Django opensearch"



# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/__init__.py


from __future__ import unicode_literals


__all__ = [
    "default_app_config",
]


default_app_config = "opensearch.apps.Config"



# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/templatetags/opensearch_tags.py


from __future__ import unicode_literals

from django import template

from opensearch import settings


__all__ = [
    "opensearch_meta",
]


register = template.Library()


@register.inclusion_tag("opensearch/templatetags/opensearch_meta.html", takes_context=True)
def opensearch_meta(context):
    """
    Return meta rel opensearch tag.
    """

    context.update({
        "DESCRIPTION": settings.DESCRIPTION,
    })

    return context



# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/urls.py


from __future__ import unicode_literals

from django.conf.urls import url
from opensearch.views import opensearch


__all__ = [
    "urlpatterns",
]


# opensearch urls
urlpatterns = [
    url(r"^opensearch\.xml$", opensearch, name="opensearch"),  # opensearch
]
